@@ -223,10 +223,14 @@ class DomparserResult():
         return self
 
     def _replace_all_links(self, html_code):
+        print("entries:")
+        for kk in self.file_map:
+            print(f"  => {kk}")
         for original_file_name in self.file_map:
             entry = self.file_map[original_file_name]
             path = original_file_name.split('/')
             path = path[len(path)-1].replace('\n', '').replace('\r', '')
+            print(f"Try to replace {path}")
             if entry[0] == 'png':
                 html_code = html_code.replace(f'<A HREF="{path}">', self.output_chart_html(entry[1]) + "<a style='display:none;'>")
             else:
